@@ -1,4 +1,4 @@
-use Tet::PDF::API;
+use Text::PDF::API;
 
 	$d=-20;
         $pdf=Text::PDF::API->new(pagesize=>'a4', 'compression'=>0);
